# DO NOT EDIT THIS FILE!
#
# This file is generated from the CDP specification. If you need to make
# changes, edit the generator and regenerate all of the modules.
#
# CDP domain: Extensions (experimental)

from __future__ import annotations
import typing
from .util import T_JSON_DICT


def load_unpacked(
    path: str,
) -> typing.Generator[T_JSON_DICT, T_JSON_DICT, str]:
    """
    Installs an unpacked extension from the filesystem similar to
    --load-extension CLI flags. Returns extension ID once the extension
    has been installed.
    :param path: Absolute file path.
    :returns: Extension id.
    """
    params: T_JSON_DICT = dict()
    params["path"] = path
    cmd_dict: T_JSON_DICT = {
        "method": "Extensions.loadUnpacked",
        "params": params,
    }
    json = yield cmd_dict
    return str(json["id"])



# DO NOT EDIT THIS FILE!
#
# This file is generated from the CDP specification. If you need to make
# changes, edit the generator and regenerate all of the modules.

from . import (
    dom,
    fetch,
    target,
)

# Instead of importing everything, make a list of all available imports.
# This will speed things up because you don't need to import everything.
__all__ = [
    "accessibility",
    "animation",
    "audits",
    "autofill",
    "background_service",
    "browser",
    "css",
    "cache_storage",
    "cast",
    "console",
    "database",
    "debugger",
    "device_access",
    "device_orientation",
    "dom",
    "dom_debugger",
    "dom_snapshot",
    "dom_storage",
    "emulation",
    "event_breakpoints",
    "extensions",
    "fed_cm",
    "fetch",
    "headless_experimental",
    "heap_profiler",
    "io",
    "indexed_db",
    "input_",
    "inspector",
    "layer_tree",
    "log",
    "media",
    "memory",
    "network",
    "overlay",
    "pwa",
    "page",
    "performance",
    "performance_timeline",
    "preload",
    "profiler",
    "runtime",
    "schema",
    "security",
    "service_worker",
    "storage",
    "system_info",
    "target",
    "tethering",
    "tracing",
    "web_audio",
    "web_authn",
]
